aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/dialogs/comp-editor-page.c
diff options
context:
space:
mode:
Diffstat (limited to 'calendar/gui/dialogs/comp-editor-page.c')
-rw-r--r--calendar/gui/dialogs/comp-editor-page.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/calendar/gui/dialogs/comp-editor-page.c b/calendar/gui/dialogs/comp-editor-page.c
index a0fdcca3a8..1a6611b017 100644
--- a/calendar/gui/dialogs/comp-editor-page.c
+++ b/calendar/gui/dialogs/comp-editor-page.c
@@ -225,7 +225,7 @@ comp_editor_page_focus_main_widget (CompEditorPage *page)
* Fills the widgets of an editor page with the data from a calendar component.
**/
void
-comp_editor_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
+comp_editor_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
{
g_return_if_fail (page != NULL);
g_return_if_fail (IS_COMP_EDITOR_PAGE (page));
@@ -247,7 +247,7 @@ comp_editor_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
* Returns: TRUE if the component could be filled, FALSE otherwise
**/
gboolean
-comp_editor_page_fill_component (CompEditorPage *page, CalComponent *comp)
+comp_editor_page_fill_component (CompEditorPage *page, ECalComponent *comp)
{
g_return_val_if_fail (page != NULL, FALSE);
g_return_val_if_fail (IS_COMP_EDITOR_PAGE (page), FALSE);
@@ -260,14 +260,14 @@ comp_editor_page_fill_component (CompEditorPage *page, CalComponent *comp)
}
/**
- * comp_editor_page_set_cal_client:
+ * comp_editor_page_set_e_cal:
* @page: An editor page
- * @client: A #CalClient object
+ * @client: A #ECal object
*
* Sets the #CalClient for the dialog page to use.
**/
void
-comp_editor_page_set_cal_client (CompEditorPage *page, CalClient *client)
+comp_editor_page_set_e_cal (CompEditorPage *page, ECal *client)
{
g_return_if_fail (page != NULL);
g_return_if_fail (IS_COMP_EDITOR_PAGE (page));
@@ -260,14 +260,14 @@ comp_editor_page_fill_component (CompEditorPage *page, CalComponent *comp)
*
- * Sets the #CalClient for the dialog page to use.
+ * Sets the #ECal for the dialog page to use.
**/
void